Renga Command Line — Renga 0.1.0.dev20170922 documentation

Join us on GitHub

# Renga Command Line

The base command for interacting with the Renga platform.

## `renga` (base command)

To list the available commands, either run `renga` with no parameters or execute `renga help`:

    $ renga help
    Usage: renga [OPTIONS] COMMAND [ARGS]...

    Check common Renga commands used in various situations.

    Options:
      --version          Print version number.
      --config FILENAME  Location of client config files.
      --config-path      Print application config path.
      --no-project       Run command outside project context.
      -h, --help         Show this message and exit.

    Commands:
      # [...]

### Configuration files

Depending on your system, you may find the configuration files used by Renga command line in a different folder. By default, the following rules are used:

MacOS:
  `~/Library/Application Support/Renga`
Unix:
  `~/.config/renga`
Windows:
  `C:\Users\<user>\AppData\Roaming\Renga`

If in doubt where to look for the configuration file, you can display its path by running `renga --config-path`.

You can specify a different location via the `RENGA_CONFIG` environment variable or the `--config` command line option. If both are specified, then the `--config` option value is used. For example:

    $ renga --config ~/renga/config/ login

instructs Renga to store the configuration files in your `~/renga/config/` directory when running the `login` command.

## `renga login`

Logging in to the Renga platform.

There is no central Renga instance, hence a platform URL must be specified. Please contact your institution administrator to obtain the URL of a running platform and necessary credentials.

### Log in to a self-hosted platform

If you want to log in to a self-hosted platform you can specify this by adding the platform endpoint.

    $ renga login http://localhost/

Note

The warning will be shown when an unsecure protocol is used.

### Non-interactive login

In some environments, you might need to run the `renga login` command non-interactively. Using the `--password-stdin` flag, you can provide a password through `STDIN`, which also prevents the password from ending up in the shell’s history or log-files.

The following example reads a password from a file, and passes it to the `renga login` command using `STDIN`:

    $ cat ~/my_secret.txt | renga login --username demo --password-stdin

## `renga init`

Create an empty Renga project or reinitialize an existing one.

### Starting a Renga project

If you have an existing directory which you want to turn into a Renga project, you can type:

    $ cd ~/my_project
    $ renga init

or:

    $ renga init ~/my_project

This creates a new subdirectory named `.renga` that contains all the necessary files for managing the project configuration.

### Storing related data

Each newly created project can get an automatically created storage space (bucket) for its related data. This feature can be controlled with the `--bucket/--no-bucket` flag.

## `renga add`

Add files to a project.

### Adding data to a project

In a newly-initialized project directory, nothing is tracked yet. You can start tracking files by adding them to Renga with e.g.:

    $ renga add input.csv

If you want to add a file to a specific bucket, you can do so by using the `--bucket-id` option.